@@ -271,13 +271,14 @@ class Pickler(object):
         if PY2 and isinstance(obj, types.FileType):
             return self._flatten_file(obj)
 
-        if type(obj) is bytes:
+        if util.is_bytes(obj):
             return self._flatten_bytestring(obj)
 
+        if util.is_primitive(obj):
+            return obj
+
         # Decimal is a primitive when use_decimal is True
-        if type(obj) in util.PRIMITIVES or (
-            self._use_decimal and isinstance(obj, decimal.Decimal)
-        ):
+        if self._use_decimal and isinstance(obj, decimal.Decimal):
             return obj
         #########################################
 
@@ -319,38 +320,37 @@ class Pickler(object):
         return [self._flatten(v) for v in obj]
 
     def _get_flattener(self, obj):
-        if type(obj) is list:
-            if self._mkref(obj):
-                return self._list_recurse
-            else:
-                self._push()
-                return self._getref
 
-        elif type(obj) is dict:
+        list_recurse = self._list_recurse
+
+        if util.is_list(obj):
             if self._mkref(obj):
-                return self._flatten_dict_obj
+                return list_recurse
             else:
                 self._push()
                 return self._getref
 
         # We handle tuples and sets by encoding them in a "(tuple|set)dict"
-        elif type(obj) is tuple:
+        if util.is_tuple(obj):
             if not self.unpicklable:
-                return self._list_recurse
+                return list_recurse
             return lambda obj: {tags.TUPLE: [self._flatten(v) for v in obj]}
 
-        elif type(obj) is set:
+        if util.is_set(obj):
             if not self.unpicklable:
-                return self._list_recurse
+                return list_recurse
             return lambda obj: {tags.SET: [self._flatten(v) for v in obj]}
 
-        elif util.is_object(obj):
-            return self._ref_obj_instance
+        if util.is_dictionary(obj):
+            return self._flatten_dict_obj
 
-        elif util.is_type(obj):
+        if util.is_type(obj):
             return _mktyperef
 
-        elif util.is_module_function(obj):
+        if util.is_object(obj):
+            return self._ref_obj_instance
+
+        if util.is_module_function(obj):
             return self._flatten_function
 
         # instance methods, lambdas, old style classes...
